..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


======================
 Invenio Framework v3
======================

**Open Source framework for large-scale digital repositories.**

.. image:: https://img.shields.io/pypi/v/invenio.svg
    :target: https://pypi.org/project/invenio/

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio.svg
    :target: https://github.com/inveniosoftware/invenio/blob/master/LICENSE

.. image:: https://travis-ci.org/inveniosoftware/invenio.svg?branch=master
    :target: https://travis-ci.org/inveniosoftware/invenio

.. image:: https://img.shields.io/badge/Discord-join%20chat-%237289da
    :target: https://discord.gg/8qatqBC

Invenio Framework is like a Swiss Army knife of battle-tested, safe and secure
modules providing you with all the features you need to build a trusted digital
repository.

**Our other products**

Looking for a turn-key Research Data Management platform? Checkout `InvenioRDM <https://inveniosoftware.org/products/rdm/>`_

Looking for a modern Integrated Library System? Checkout `InvenioILS <https://inveniosoftware.org/products/ils/>`_

**Built with Invenio Framework**

See examples on https://inveniosoftware.org/products/framework/ and https://inveniosoftware.org/showcase/.
